#
# spec file for package vit
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vit
Version:        2.3.2
Release:        1.1
Summary:        Visual Interactive Taskwarrior full-screen terminal interface
License:        MIT
Group:          Productivity/Office/Organizers
URL:            https://github.com/scottkosty/vit
Source:         https://files.pythonhosted.org/packages/source/v/vit/vit-%{version}.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base >= 3.7
BuildRequires:  python3-setuptools
BuildRequires:  python3-tasklib
BuildRequires:  python3-urwid
Requires:       python3-base >= 3.7
Requires:       python3-tasklib
Requires:       python3-urwid
Requires:       taskwarrior
BuildArch:      noarch

%description
Visual Interactive Taskwarrior full-screen terminal interface.
Features:
 * Fully-customizable key bindings (default Vim-like)
 * Uncluttered display
 * No mouse
 * Speed
 * Per-column colorization
 * Advanced tab completion
 * Multiple/customizable themes
 * Override/customize column formatters
 * Intelligent sub-project indenting

%prep
%setup -q -n vit-%{version}

%build
%python3_build

%install
%python3_install
install -Dm644 scripts/bash/vit.bash_completion %{buildroot}%{_datadir}/bash-completion/completions/vit
%fdupes %{buildroot}%{python3_sitelib}

%check
python3 -m unittest

%files
%doc COLOR.md CUSTOMIZE.md README.md
%license LICENSE
%{_bindir}/vit
%{_datadir}/bash-completion/completions/vit
%{python3_sitelib}/*

%changelog
* Mon Oct 23 2023 Mia Herkt <mia@0x0.st>
- Update to 2.3.2
  * fix(py3.12): SafeConfigParser -> ConfigParser
  * fix: Clarify how to interact inside 'Denotate' window
    gh#vit-project/vit#340
* Fri Jul 14 2023 Mia Herkt <mia@0x0.st>
- Update to 2.3.1
  * fix: urwid.str_util import fails on some distros
    gh#vit-project/vit#339
* Mon Apr 24 2023 Mia Herkt <mia@0x0.st>
- Update to 2.3.0
  * Allow flash configuration
  * correctly calculate text width of full-width characters
  * Fix required minimum Python version
  * add documentation for auto-refresh configuration
  * place IS_VIT_INSTANCE into environ earlier
  * example hook for intelligent VIT refresh
  * sample script to externally refresh VIT instances
  * add Bash function example for vit wrapper
  * add pid_dir option to [vit] section
    See sample config.ini for details on usage
  * add basic signal support
    + SIGUSR1: refresh (equivalent to hitting refresh key in VIT)
    + SIGTERM/SIGINT/SIGQUIT: quit VIT cleanly
  * more user-friendly error message for unsupported color
    definitions
* Tue May 24 2022 Mia Herkt <mia@0x0.st>
- Update to 2.2.0
  * Require Python >= 3.7
  * Simplify timezone handling
  * Replace pytz and tzlocal by zoneinfo
  * Make vit respect taskrc in config.ini
* Wed Jun 23 2021 Mia Herkt <mia@0x0.st>
- Update to 2.1.0
  This release adds support for TaskWarrior >= 2.5.2
  The release includes a breaking change to the keybinding parser,
  and may affect users who have implemented custom keybindings in
  their configuration.
  * fix: blocked marker displaying for deleted/completed depends
  * add quick start instructions to README
  * [BREAKING CHANGE] correctly parse bracket expressions for
    keybinding keys
  * Add 'abort_backspace' config, False by default. If true,
    hitting backspace against an empty prompt aborts the prompt.
  * Use Python.ignore from github
* Wed Dec 16 2020 Mia Herkt <mia@0x0.st>
- Switch to 2.x branch, update to 2.0.0
  Complete ground up rewrite in Python, feature-complete with VIT 1.x
  New features:
  * Advanced tab completion
  * Per-column colorization with markers (see COLOR.md)
  * Intelligent sub-project indenting
  * Multiple/customizable themes (see CUSTOMIZE.md)
  * Override/customize column formatters (see CUSTOMIZE.md)
  * Fully-customizable key bindings (see CUSTOMIZE.md)
  * Table-row striping
  * Show version/context/report execution time in status area
  * Customizable config dir (see CUSTOMIZE.md)
  * Command line bash completion wrapper
  * Context support
  This release also changes the software license from GPL to MIT.
  See https://github.com/vit-project/vit/blob/2.x/UPGRADE.md for
  instructions on how to upgrade from VIT 1.3.
* Tue Jan  8 2019 Martin Herkt <9+suse@cirno.systems>
- Use %%license
- Update to version 1.3~20190107.g96134b3:
  * Make the build reproducible
* Wed Sep 26 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to snapshot 1.3~20180806.gdbacada
  * Use fixed build date (boo#1047218)
* Sat Dec 23 2017 9@cirno.systems
- Update to snapshot 1.3~20171222.g2d6ec2c
  * Allow tag lists to be separated by commas
* Fri Dec  1 2017 9@cirno.systems
- Change version format - use ~ instead of + so future release of
  1.3 will take precedence over snapshot package of dev branch.
* Fri Dec  1 2017 9@cirno.systems
- Correct RPM category
* Fri Dec  1 2017 9@cirno.systems
- Switch to disabled services
- Correct version output
* Mon Nov 27 2017 9@cirno.systems
- Fix runtime perl dependencies
* Mon Nov 27 2017 9@cirno.systems
- switch to git 1.3 branch
* Mon Nov 27 2017 9@cirno.systems
- init, 1.2
